HNode

Enum HNode 

pub enum HNode<ET: EngineTypes> {
Show 19 variants Penalty(i32), Mark(usize, TokenList<ET::Token>), Whatsit(WhatsitNode<ET>), HSkip(Skip<ET::Dim>), HFil, HFill, HFilneg, Hss, Space, HKern(ET::Dim), Leaders(Leaders<ET>), Box(TeXBox<ET>), VRule { width: Option<ET::Dim>, height: Option<ET::Dim>, depth: Option<ET::Dim>, start: SourceRef<ET>, end: SourceRef<ET>, }, Insert(usize, Box<[VNode<ET>]>), VAdjust(Box<[VNode<ET>]>), MathGroup(MathGroup<ET>), Char { char: ET::Char, font: <ET::FontSystem as FontSystem>::Font, }, Accent { accent: ET::Char, char: ET::Char, font: <ET::FontSystem as FontSystem>::Font, }, Custom(ET::CustomNode),
}
A horizontal list node.

Variants



Penalty(i32)

A penalty node, as produced by \penalty.



Mark(usize, TokenList<ET::Token>)

A mark node, as produced by \mark.



Whatsit(WhatsitNode<ET>)

A whatsit node, as produced by \special, \write, etc.



HSkip(Skip<ET::Dim>)

A glue node, as produced by \hskip.



HFil

A glue node, as produced by \hfil.



HFill

A glue node, as produced by \hfill.



HFilneg

A glue node, as produced by \hfilneg.



Hss

A glue node, as produced by \hss.



Space

A glue node, as produced by a space character.



HKern(ET::Dim)

A kern node, as produced by \kern.



Leaders(Leaders<ET>)

Leaders, as produced by \leaders or \cleaders or \xleaders.



Box(TeXBox<ET>)

A box node, as produced by \hbox, \vbox, \vtop, etc.



VRule

A rule node, as produced by \vrule.

Fields

width: Option<ET::Dim>

The provided width of the rule.

height: Option<ET::Dim>

The provided height of the rule.

depth: Option<ET::Dim>

The provided depth of the rule.

start: SourceRef<ET>

The source reference for the start of the rule.

end: SourceRef<ET>

The source reference for the end of the rule.



Insert(usize, Box<[VNode<ET>]>)

An insertion node, as produced by \insert.



VAdjust(Box<[VNode<ET>]>)

A vadjust node, as produced by \vadjust; its contents will migrate to the surrounding vertical list eventually.



MathGroup(MathGroup<ET>)

A math list, as produced by $...$ or $$...$$.



Char

A character node, as produced by a character.

Fields

char: ET::Char

The character.

font: <ET::FontSystem as FontSystem>::Font

The current font



Accent

An \accent node.

Fields

accent: ET::Char

The accent character.

char: ET::Char

The lower character.

font: <ET::FontSystem as FontSystem>::Font

The current font



Custom(ET::CustomNode)

A custom node.